==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/RequestContractArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.RequestContractArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Operation request details.
 * @property description Operation request description.
 * @property headers Collection of operation request headers.
 * @property queryParameters Collection of operation request query parameters.
 * @property representations Collection of operation request representations.
 */
public data class RequestContractArgs(
    public val description: Output<String>? = null,
    public val headers: Output<List<ParameterContractArgs>>? = null,
    public val queryParameters: Output<List<ParameterContractArgs>>? = null,
    public val representations: Output<List<RepresentationContractArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.RequestContractArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.inputs.RequestContractArgs =
        com.pulumi.azurenative.apimanagement.inputs.RequestContractArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .headers(
                headers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .queryParameters(
                queryParameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .representations(
                representations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RequestContractArgs].
 */
@PulumiTagMarker
public class RequestContractArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var headers: Output<List<ParameterContractArgs>>? = null

    private var queryParameters: Output<List<ParameterContractArgs>>? = null

    private var representations: Output<List<RepresentationContractArgs>>? = null

    /**
     * @param value Operation request description.
     */
    @JvmName("osrqaeivjbkqlbus")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Collection of operation request headers.
     */
    @JvmName("ikufaedbulwnxpib")
    public suspend fun headers(`value`: Output<List<ParameterContractArgs>>) {
        this.headers = value
    }

    @JvmName("rvcpxxdofavbdwcp")
    public suspend fun headers(vararg values: Output<ParameterContractArgs>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values Collection of operation request headers.
     */
    @JvmName("vxcsnehefkfkhsfg")
    public suspend fun headers(values: List<Output<ParameterContractArgs>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value Collection of operation request query parameters.
     */
    @JvmName("dshdmrbkvvduoims")
    public suspend fun queryParameters(`value`: Output<List<ParameterContractArgs>>) {
        this.queryParameters = value
    }

    @JvmName("hjpmtkiroclnpcld")
    public suspend fun queryParameters(vararg values: Output<ParameterContractArgs>) {
        this.queryParameters = Output.all(values.asList())
    }

    /**
     * @param values Collection of operation request query parameters.
     */
    @JvmName("jcyvfckfsaxmqgiu")
    public suspend fun queryParameters(values: List<Output<ParameterContractArgs>>) {
        this.queryParameters = Output.all(values)
    }

    /**
     * @param value Collection of operation request representations.
     */
    @JvmName("soulyxfcjtwacnvd")
    public suspend fun representations(`value`: Output<List<RepresentationContractArgs>>) {
        this.representations = value
    }

    @JvmName("qqhnhciaaesnfnaa")
    public suspend fun representations(vararg values: Output<RepresentationContractArgs>) {
        this.representations = Output.all(values.asList())
    }

    /**
     * @param values Collection of operation request representations.
     */
    @JvmName("ktdvwrxrjcldoxwa")
    public suspend fun representations(values: List<Output<RepresentationContractArgs>>) {
        this.representations = Output.all(values)
    }

    /**
     * @param value Operation request description.
     */
    @JvmName("beowqaudqxeqaqlv")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Collection of operation request headers.
     */
    @JvmName("feybjqlwdvqcgaqo")
    public suspend fun headers(`value`: List<ParameterContractArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param argument Collection of operation request headers.
     */
    @JvmName("gthytojbcxspxmia")
    public suspend fun headers(argument: List<suspend ParameterContractArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ParameterContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument Collection of operation request headers.
     */
    @JvmName("ugoeiyxlddocpyik")
    public suspend fun headers(vararg argument: suspend ParameterContractArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ParameterContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument Collection of operation request headers.
     */
    @JvmName("auhmmwiymnxijuco")
    public suspend fun headers(argument: suspend ParameterContractArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ParameterContractArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param values Collection of operation request headers.
     */
    @JvmName("gucruykpdgetvkpt")
    public suspend fun headers(vararg values: ParameterContractArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value Collection of operation request query parameters.
     */
    @JvmName("ohcaphjvsbdgexft")
    public suspend fun queryParameters(`value`: List<ParameterContractArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryParameters = mapped
    }

    /**
     * @param argument Collection of operation request query parameters.
     */
    @JvmName("tnafolgkwrustyks")
    public suspend
    fun queryParameters(argument: List<suspend ParameterContractArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ParameterContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.queryParameters = mapped
    }

    /**
     * @param argument Collection of operation request query parameters.
     */
    @JvmName("cjmibqdvtjwiedco")
    public suspend fun queryParameters(
        vararg
        argument: suspend ParameterContractArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ParameterContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.queryParameters = mapped
    }

    /**
     * @param argument Collection of operation request query parameters.
     */
    @JvmName("hhlttvgfyoxvagnm")
    public suspend fun queryParameters(argument: suspend ParameterContractArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ParameterContractArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.queryParameters = mapped
    }

    /**
     * @param values Collection of operation request query parameters.
     */
    @JvmName("fgrqwcnakjutlceh")
    public suspend fun queryParameters(vararg values: ParameterContractArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.queryParameters = mapped
    }

    /**
     * @param value Collection of operation request representations.
     */
    @JvmName("nuqrsfsevkryvmsg")
    public suspend fun representations(`value`: List<RepresentationContractArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.representations = mapped
    }

    /**
     * @param argument Collection of operation request representations.
     */
    @JvmName("vpjviulgxcmionah")
    public suspend
    fun representations(argument: List<suspend RepresentationContractArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RepresentationContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.representations = mapped
    }

    /**
     * @param argument Collection of operation request representations.
     */
    @JvmName("gapygdbpfgqjmrkb")
    public suspend fun representations(
        vararg
        argument: suspend RepresentationContractArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RepresentationContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.representations = mapped
    }

    /**
     * @param argument Collection of operation request representations.
     */
    @JvmName("vkqlcqdmlxrykacy")
    public suspend
    fun representations(argument: suspend RepresentationContractArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RepresentationContractArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.representations = mapped
    }

    /**
     * @param values Collection of operation request representations.
     */
    @JvmName("apeqmhondogbbohw")
    public suspend fun representations(vararg values: RepresentationContractArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.representations = mapped
    }

    internal fun build(): RequestContractArgs = RequestContractArgs(
        description = description,
        headers = headers,
        queryParameters = queryParameters,
        representations = representations,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/RequestContractArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.RequestContractArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Operation request details.
 * @property description Operation request description.
 * @property headers Collection of operation request headers.
 * @property queryParameters Collection of operation request query parameters.
 * @property representations Collection of operation request representations.
 */
public data class RequestContractArgs(
    public val description: Output<String>? = null,
    public val headers: Output<List<ParameterContractArgs>>? = null,
    public val queryParameters: Output<List<ParameterContractArgs>>? = null,
    public val representations: Output<List<RepresentationContractArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.RequestContractArgs> {
    override fun toJava(): com.pulumi.azurenative.apimanagement.inputs.RequestContractArgs =
        com.pulumi.azurenative.apimanagement.inputs.RequestContractArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .headers(
                headers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .queryParameters(
                queryParameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .representations(
                representations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RequestContractArgs].
 */
@PulumiTagMarker
public class RequestContractArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var headers: Output<List<ParameterContractArgs>>? = null

    private var queryParameters: Output<List<ParameterContractArgs>>? = null

    private var representations: Output<List<RepresentationContractArgs>>? = null

    /**
     * @param value Operation request description.
     */
    @JvmName("kcgclmrhhfagjaal")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Collection of operation request headers.
     */
    @JvmName("nbkxivmfirfumiie")
    public suspend fun headers(`value`: Output<List<ParameterContractArgs>>) {
        this.headers = value
    }

    @JvmName("wfxpihldiqqhdysx")
    public suspend fun headers(vararg values: Output<ParameterContractArgs>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values Collection of operation request headers.
     */
    @JvmName("ibkpewpbaxjompvv")
    public suspend fun headers(values: List<Output<ParameterContractArgs>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value Collection of operation request query parameters.
     */
    @JvmName("qfuqrgftoscmkvro")
    public suspend fun queryParameters(`value`: Output<List<ParameterContractArgs>>) {
        this.queryParameters = value
    }

    @JvmName("pjrbpbevgnobpayo")
    public suspend fun queryParameters(vararg values: Output<ParameterContractArgs>) {
        this.queryParameters = Output.all(values.asList())
    }

    /**
     * @param values Collection of operation request query parameters.
     */
    @JvmName("kqycehvyongjnxax")
    public suspend fun queryParameters(values: List<Output<ParameterContractArgs>>) {
        this.queryParameters = Output.all(values)
    }

    /**
     * @param value Collection of operation request representations.
     */
    @JvmName("pqrfcqofridmvgkn")
    public suspend fun representations(`value`: Output<List<RepresentationContractArgs>>) {
        this.representations = value
    }

    @JvmName("dkqogjafvwlvylvv")
    public suspend fun representations(vararg values: Output<RepresentationContractArgs>) {
        this.representations = Output.all(values.asList())
    }

    /**
     * @param values Collection of operation request representations.
     */
    @JvmName("orepevcouxaibsdn")
    public suspend fun representations(values: List<Output<RepresentationContractArgs>>) {
        this.representations = Output.all(values)
    }

    /**
     * @param value Operation request description.
     */
    @JvmName("rkhbsrepkagrcdjj")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Collection of operation request headers.
     */
    @JvmName("ksqupkiimtqnymtg")
    public suspend fun headers(`value`: List<ParameterContractArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param argument Collection of operation request headers.
     */
    @JvmName("kxrkvupvhudkuyvx")
    public suspend fun headers(argument: List<suspend ParameterContractArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ParameterContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument Collection of operation request headers.
     */
    @JvmName("nkfkhetdlohfinnw")
    public suspend fun headers(vararg argument: suspend ParameterContractArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ParameterContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument Collection of operation request headers.
     */
    @JvmName("amxmskwcymyaauch")
    public suspend fun headers(argument: suspend ParameterContractArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ParameterContractArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param values Collection of operation request headers.
     */
    @JvmName("jkhviuvpqqsgapkl")
    public suspend fun headers(vararg values: ParameterContractArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value Collection of operation request query parameters.
     */
    @JvmName("dpojfdffndymmrdg")
    public suspend fun queryParameters(`value`: List<ParameterContractArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryParameters = mapped
    }

    /**
     * @param argument Collection of operation request query parameters.
     */
    @JvmName("hjaqewkibjovxolp")
    public suspend
    fun queryParameters(argument: List<suspend ParameterContractArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ParameterContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.queryParameters = mapped
    }

    /**
     * @param argument Collection of operation request query parameters.
     */
    @JvmName("ftbcmafofqshnjvn")
    public suspend fun queryParameters(
        vararg
        argument: suspend ParameterContractArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ParameterContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.queryParameters = mapped
    }

    /**
     * @param argument Collection of operation request query parameters.
     */
    @JvmName("kxwotkrrvmalheeh")
    public suspend fun queryParameters(argument: suspend ParameterContractArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ParameterContractArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.queryParameters = mapped
    }

    /**
     * @param values Collection of operation request query parameters.
     */
    @JvmName("fekfqvatslddhgpv")
    public suspend fun queryParameters(vararg values: ParameterContractArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.queryParameters = mapped
    }

    /**
     * @param value Collection of operation request representations.
     */
    @JvmName("bovgvffwrkfrvyab")
    public suspend fun representations(`value`: List<RepresentationContractArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.representations = mapped
    }

    /**
     * @param argument Collection of operation request representations.
     */
    @JvmName("vtnhieohwajwogox")
    public suspend
    fun representations(argument: List<suspend RepresentationContractArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RepresentationContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.representations = mapped
    }

    /**
     * @param argument Collection of operation request representations.
     */
    @JvmName("emhoxwsqgoiqmmkg")
    public suspend fun representations(
        vararg
        argument: suspend RepresentationContractArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RepresentationContractArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.representations = mapped
    }

    /**
     * @param argument Collection of operation request representations.
     */
    @JvmName("hwjgaohblphradvc")
    public suspend
    fun representations(argument: suspend RepresentationContractArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RepresentationContractArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.representations = mapped
    }

    /**
     * @param values Collection of operation request representations.
     */
    @JvmName("ybodftkomjovxxpy")
    public suspend fun representations(vararg values: RepresentationContractArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.representations = mapped
    }

    internal fun build(): RequestContractArgs = RequestContractArgs(
        description = description,
        headers = headers,
        queryParameters = queryParameters,
        representations = representations,
    )
}
